@@ -2,9 +2,10 @@ package Mail::Milter::Authentication;
 use strict;
 use warnings;
 use base 'Net::Server::PreFork';
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use English qw{ -no_match_vars };
+use ExtUtils::Installed;
 use Mail::Milter::Authentication::Config qw{ get_config };
 use Mail::Milter::Authentication::Constants qw{ :all };
 use Mail::Milter::Authentication::DNSCache;
@@ -19,10 +20,29 @@ use vars qw(@ISA);
 
 sub _warn {
     my ( $msg ) = @_;
-    print STDERR $msg;
+    my @parts = split "\n", $msg;
+    foreach my $part ( @parts ) {
+        next if $part eq q{};
+        print STDERR scalar localtime . " authentication_milter[$PID] $part\n";
+    }
     return;
 }
 
+sub get_installed_handlers {
+    my @installed_handlers;
+    my $installed = ExtUtils::Installed->new( 'skip_cwd' => 1 );
+    foreach my $module ( grep { /Mail::Milter::Authentication/ } $installed->modules() ) {
+        FILE:
+        foreach my $file ( grep { /Mail\/Milter\/Authentication\/Handler\/\w+\.pm$/ } $installed->files( $module ) ) {
+            next FILE if ! -e $file;
+            my ( $handler ) = reverse split '/', $file;
+            $handler =~ s/\.pm$//;
+            push @installed_handlers, $handler;
+        }
+    }
+    return \@installed_handlers;
+}
+
 sub pre_loop_hook {
     my ( $self ) = @_;
 
@@ -250,7 +270,7 @@ sub start {
     local $SIG{__WARN__} = sub {
         foreach my $msg ( @_ ) {
             syslog( LOG_ERR, "Warning: $msg" );
-            warn scalar localtime . " [$PID] Warning: $msg";
+            _warn( "Warning: $msg" );
         }
         return;
     };
@@ -280,14 +300,13 @@ sub start {
                     "servers=$min_children/$max_children",
                     "spares=$min_spare_children/$max_spare_children",
                     "requests=$max_requests_per_child",
-                    "\n",
                 )
             );
             $srvargs{'background'}        = 1;
             $srvargs{'setsid'}            = 1;
         }
         else {
-            _warn("Not running as root, daemonize ignored!\n");
+            _warn("Not running as root, daemonize ignored!");
         }
     }
     $srvargs{'pid_file'}          = $pid_file;
@@ -306,12 +325,12 @@ sub start {
         my $user  = $config->{'runas'};
         my $group = $config->{'rungroup'};
         if ( $user && $group ) {
-        _warn("run as user=$user group=$group\n");
+        _warn("run as user=$user group=$group");
             $srvargs{'user'}  = $user;
             $srvargs{'group'} = $group;
         }
         else {
-            _warn("No runas details supplied, could not drop privs - be careful!\n");
+            _warn("No runas details supplied, could not drop privs - be careful!");
         }
         # Note, Chroot requires a chroot environment which is out of scope at present
         if ( $config->{'error_log'} ) {
@@ -323,12 +342,12 @@ sub start {
             chown $uid, $gid, $config->{'error_log'};
         }
         if ( exists( $config->{'chroot'} ) ) {
-            _warn('Chroot to ' . $config->{'chroot'} . "\n");
+            _warn('Chroot to ' . $config->{'chroot'});
             $srvargs{'chroot'} = $config->{'chroot'};
         }
     }
     else {
-        _warn("Not running as root, could not drop privs - be careful!\n");
+        _warn("Not running as root, could not drop privs - be careful!");
     }
 
     my $connections = {};
@@ -358,7 +377,6 @@ sub start {
                     "host=$host",
                     "port=$path",
                     "backlog=$listen_backlog",
-                    "\n",
                 )
             );
             push @ports, {
@@ -374,7 +392,6 @@ sub start {
                     'listening on unix',
                     "socket=$path",
                     "backlog=$listen_backlog",
-                    "\n",
                 )
             );
             push @ports, {
@@ -384,7 +401,7 @@ sub start {
 
             if ($umask) {
                 umask ( oct( $umask ) );
-                _warn( 'setting umask to ' . $umask . "\n" );
+                _warn( 'setting umask to ' . $umask );
             }
 
         }
@@ -396,7 +413,7 @@ sub start {
     $srvargs{'port'} = \@ports;
     $srvargs{'listen'} = $listen_backlog;
 
-    _warn "\nStarting server\n";
+    _warn "==========\nStarting server\n==========";
     __PACKAGE__->run( %srvargs );
 
     # Never reaches here.
@@ -411,6 +428,14 @@ sub fatal {
     die "$error\n";
 }
 
+sub fatal_global {
+    my ( $self, $error ) = @_;
+    $self->logerror( "Child process $PID signalling global shut down due to fatal error: $error" );
+    my $ppid = $self->{'server'}->{'ppid'};
+    kill 'HUP', $ppid;
+    die "$error\n";
+}
+
 sub setup_handlers {
     my ( $self ) = @_;
 
@@ -537,7 +562,7 @@ sub sort_callbacks {
 
         my $defer_count = scalar @defer;
         if ( $defer_count == $todo_count ) {
-            $self->fatal('Could not build order list');
+            $self->fatal_global('Could not build order list');
         }
         $todo_count = $defer_count;
         @todo = @defer;
@@ -577,7 +602,7 @@ sub logerror {
             $line = $self->{'smtp'}->{'queue_id'} . ': ' . $line;
         }
     }
-    _warn( scalar localtime . " [$PID] $line\n" ) if $config->{'logtoerr'};
+    _warn( $line ) if $config->{'logtoerr'};
     syslog( LOG_ERR, $line );
     return;
 }
@@ -590,7 +615,7 @@ sub loginfo {
             $line = $self->{'smtp'}->{'queue_id'} . ': ' . $line;
         }
     }
-    _warn( scalar localtime . " [$PID] $line\n" ) if $config->{'logtoerr'};
+    _warn( $line ) if $config->{'logtoerr'};
     syslog( LOG_INFO, $line );
     return;
 }
@@ -603,8 +628,8 @@ sub logdebug {
             $line = $self->{'smtp'}->{'queue_id'} . ': ' . $line;
         }
     }
-    _warn( scalar localtime . " [$PID] $line\n" ) if $config->{'logtoerr'};
     if ( $config->{'debug'} ) {
+        _warn( $line ) if $config->{'logtoerr'};
         syslog( LOG_DEBUG, $line );
     }
     return;
@@ -628,6 +653,18 @@ Subclass of Net::Server::PreFork for bringing up the main server process for aut
 
 Please see Net::Server docs for more detail of the server code.
 
+Please see the output of 'authentication_milter --help' for usage help.
+
+=head1 FUNCTIONS
+
+=over
+
+=item I<get_installed_handlers()>
+
+Return an array ref of installed handler modules.
+
+=back
+
 =head1 METHODS
 
 =over
@@ -655,7 +692,11 @@ Start the server. This method does not return.
 
 =item I<fatal($error)>
 
-Log a fatal error and die
+Log a fatal error and die in child
+
+=item I<fatal_global($error)>
+
+Log a fatal error and die in child and parent
 
 =item I<setup_handlers()>
 
