@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Client;
 
 use strict;
 use warnings;
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use Data::Dumper;
 use Digest::MD5 qw{ md5_base64 };
@@ -473,8 +473,8 @@ The full documentation of Net::Milter will follow this paragraph.
 package Mail::Milter::Authentication::Net::Milter;
 use strict;
 use Carp;
-use vars qw($VERSION $DEBUG);
-$VERSION='0.09';
+use vars qw($DEBUG);
+use version; our $VERSION = version->declare('v1.0.0');
 $DEBUG=0;
 
 use constant PROTOCOL_NEGATION => 0; 
