@@ -1,7 +1,7 @@
 package Mail::Milter::Authentication::Handler;
 use strict;
 use warnings;
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use Email::Address;
 use English qw{ -no_match_vars };
@@ -757,10 +757,6 @@ sub dbgout {
     $key   = q{--} if ! defined $key;
     $value = q{--} if ! defined $value;
 
-    if ( $self->config()->{'logtoerr'} ) {
-        Mail::Milter::Authentication::_warn( scalar localtime . "[$PID] $queue_id: $key: $value\n" );
-    }
-
     my $config = $self->config();
     if (
         $priority == LOG_DEBUG
@@ -770,6 +766,10 @@ sub dbgout {
         return;
     }
 
+    if ( $self->config()->{'logtoerr'} ) {
+        Mail::Milter::Authentication::_warn( "$queue_id: $key: $value" );
+    }
+
     my $top_handler = $self->get_top_handler();
     if ( !exists( $top_handler->{'dbgout'} ) ) {
         $top_handler->{'dbgout'} = [];
