@@ -2,10 +2,14 @@ package Mail::Milter::Authentication::Handler::AddID;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use Sys::Syslog qw{:standard :macros};
 
+sub default_config {
+    return {};
+}
+
 sub eom_callback {
 
     # On HELO
@@ -26,6 +30,12 @@ __END__
 
 Simple module which adds a header to all email processed.
 
+This is meant as an example only.
+
+=head1 CONFIGURATION
+
+No configuration options exist for this handler.
+
 =head1 SYNOPSIS
 
 =head1 AUTHORS
