@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::DKIM;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use Data::Dumper;
 use English qw{ -no_match_vars };
@@ -12,6 +12,15 @@ use Mail::DKIM;
 use Mail::DKIM::Verifier;
 use Mail::DKIM::DNS;
 
+sub default_config {
+    return {
+        'hide_none'         => 0,
+        'check_adsp'        => 1,
+        'show default_adsp' => 0,
+        'adsp_hide_none'    => 0,
+    };
+}
+
 sub envfrom_callback {
     my ( $self, $env_from ) = @_;
     $self->{'failmode'}     = 0;
@@ -379,6 +388,15 @@ __END__
 
 Module for validation of DKIM and DomainKeys signatures, and application of ADSP policies.
 
+=head1 CONFIGURATION
+
+        "DKIM" : {                                      | Config for the DKIM Module
+            "hide_none"         : 0,                    | Hide auth line if the result is 'none'
+            "check_adsp"        : 1,                    | Also check for ADSP
+            "show_default_adsp" : 0,                    | Show the default ADSP result
+            "adsp_hide_none"    : 0                     | Hide auth ADSP if the result is 'none'
+        },
+
 =head1 SYNOPSIS
 
 =head1 AUTHORS
