@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::DMARC;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use Data::Dumper;
 use English qw{ -no_match_vars };
@@ -12,6 +12,15 @@ use Mail::DMARC::PurePerl;
 
 my $PSL_CHECKED_TIME;
 
+sub default_config {
+    return {
+        'hide_none'      => 0,
+        'detect_list_id' => 1,
+        'report_skip_to' => [ 'my_report_from_address@example.com' ],
+        'no_report'      => 0,
+    };
+}
+
 sub pre_loop_setup {
     my ( $self ) = @_;
     $PSL_CHECKED_TIME = time;
@@ -379,6 +388,23 @@ __END__
 
 Module implementing the DMARC standard checks.
 
+This handler requires the SPF and DKIM handlers to be installed and active.
+
+=head1 CONFIGURATION
+
+        "DMARC" : {                                     | Config for the DMARC Module
+                                                        | Requires DKIM and SPF
+            "hide_none"      : 0,                       | Hide auth line if the result is 'none'
+            "detect_list_id" : "1",                     | Detect a list ID and modify the DMARC authentication header
+                                                        | to note this, useful when making rules for junking email
+                                                        | as mailing lists frequently cause false DMARC failures.
+            "report_skip_to" : [                        | Do not send DMARC reports for emails to these addresses.
+                "dmarc@yourdomain.com",                 | This can be used to avoid report loops for email sent to
+                "dmarc@example.com"                     | your report from addresses.
+            ],
+            "no_report" : "1"                           | If set then we will not attempt to store DMARC reports.
+        },
+
 =head1 SYNOPSIS
 
 =head1 AUTHORS
