@@ -2,10 +2,14 @@ package Mail::Milter::Authentication::Handler::LocalIP;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use Sys::Syslog qw{:standard :macros};
 
+sub default_config {
+    return {};
+}
+
 sub is_local_ip_address {
     my ( $self, $ip ) = @_;
     my $ip_address = $ip->ip();
@@ -69,6 +73,10 @@ __END__
 
 Detect a Local IP address and act accordingly.
 
+=head1 CONFIGURATION
+
+No configuration options exist for this handler.
+
 =head1 SYNOPSIS
 
 =head1 AUTHORS
