@@ -2,10 +2,14 @@ package Mail::Milter::Authentication::Handler::PTR;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use Sys::Syslog qw{:standard :macros};
 
+sub default_config {
+    return {};
+}
+
 sub helo_callback {
 
     # On HELO
@@ -54,6 +58,12 @@ __END__
 
 Check DNS PTR Records match.
 
+This handler requires the IPRev handler to be installed and active.
+
+=head1 CONFIGURATION
+
+No configuration options exist for this handler.
+
 =head1 SYNOPSIS
 
 =head1 AUTHORS
