@@ -2,12 +2,18 @@ package Mail::Milter::Authentication::Handler::SPF;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use Sys::Syslog qw{:standard :macros};
 
 use Mail::SPF;
 
+sub default_config {
+    return {
+        'hide_none' => 0,
+    };
+}
+
 sub setup_callback {
     my ( $self ) = @_;
 
@@ -156,6 +162,12 @@ __END__
 
 Implements the SPF standard checks.
 
+=head1 CONFIGURATION
+
+        "SPF" : {                                       | Config for the SPF Module
+            "hide_none" : 0                             | Hide auth line if the result is 'none'
+        },
+
 =head1 SYNOPSIS
 
 =head1 AUTHORS
