@@ -2,10 +2,17 @@ package Mail::Milter::Authentication::Handler::Sanitize;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use Sys::Syslog qw{:standard :macros};
 
+sub default_config {
+    return {
+        'hosts_to_remove' => [ 'example.com', 'example.net' ],
+        'remove_headeres' => 'yes',
+    };
+}
+
 sub is_hostname_mine {
     my ( $self, $check_hostname ) = @_;
     my $config = $self->handler_config();
@@ -111,6 +118,21 @@ __END__
 
 Remove unauthorized (forged) Authentication-Results headers from processed email.
 
+=head1 CONFIGURATION
+
+        "Sanitize" : {                                  | Config for the Sanitize Module
+                                                        | Remove conflicting Auth-results headers from inbound mail
+            "hosts_to_remove" : [                       | Hostnames (including subdomains thereof) for which we
+                "example.com",                          | want to remove existing authentication results headers.
+                "example.net"
+            ],
+            "remove_headers" : "yes"                    | Remove headers with conflicting host names (as defined above)
+                                                        | "no" : do not remove
+                                                        | "yes" : remove and add a header for each one
+                                                        | "silent" : remove silently
+                                                        | Does not run for trusted IP address connections
+        }
+
 =head1 SYNOPSIS
 
 =head1 AUTHORS
