@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::SenderID;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use Sys::Syslog qw{:standard :macros};
 
@@ -10,6 +10,12 @@ use Mail::SPF;
 
 use Mail::Milter::Authentication::Handler::SPF;
 
+sub default_config {
+    return {
+        'hide_none' => 1,
+    };
+}
+
 sub setup_callback {
     my ( $self ) = @_;
     # Call connect_callback from SPF handler to setup object creation
@@ -119,6 +125,12 @@ __END__
 
 Implements the SenderID standard checks.
 
+=head1 CONFIGURATION
+
+        "SenderID" : {                                  | Config for the SenderID Module
+            "hide_none" : 1                             | Hide auth line if the result is 'none'
+        },
+
 =head1 SYNOPSIS
 
 =head1 AUTHORS
