@@ -2,11 +2,17 @@ package Mail::Milter::Authentication::Handler::TrustedIP;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v1.0.0');
 
 use Net::IP;
 use Sys::Syslog qw{:standard :macros};
 
+sub default_config {
+    return {
+        'trusted_ip_list' => [],
+    };
+}
+
 sub is_trusted_ip_address {
     my ( $self, $ip_obj ) = @_;
     my $config = $self->handler_config();
@@ -57,6 +63,17 @@ __END__
 
 Detect a trusted IP address and act accordingly.
 
+=head1 CONFIGURATION
+
+        "TrustedIP" : {                                 | Config the the TruetedIP Module
+                                                        | Check for TrustedIP Addresses
+            "trusted_ip_list" : [                       | List of IP Addresses considered to be trusted
+                "100.200.100.2",                        | CIDR Ranges are valid syntax
+                "2001:44c2:3881:aa00::/56",
+                "2001:44b8:3021:123:dead:beef:abcd:1234"
+            ],
+        },
+
 =head1 SYNOPSIS
 
 =head1 AUTHORS
